@@ -172,18 +172,18 @@ class CfnGitHubRepository(
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
     def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         '''The CloudFormation resource type name for this resource class.'''
         return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="cfnProperties")
     def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="repositoryName")
     def repository_name(self) -> builtins.str:
         '''The name of the repository you want to create in GitHub with AWS CloudFormation stack creation.
@@ -199,7 +199,7 @@ class CfnGitHubRepository(
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "repositoryName", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="repositoryOwner")
     def repository_owner(self) -> builtins.str:
         '''The GitHub user name for the owner of the GitHub repository to be created.
@@ -217,7 +217,7 @@ class CfnGitHubRepository(
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "repositoryOwner", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="code")
     def code(
         self,
@@ -238,7 +238,7 @@ class CfnGitHubRepository(
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "code", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="connectionArn")
     def connection_arn(self) -> typing.Optional[builtins.str]:
         '''``AWS::CodeStar::GitHubRepository.ConnectionArn``.
@@ -254,7 +254,7 @@ class CfnGitHubRepository(
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "connectionArn", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="enableIssues")
     def enable_issues(
         self,
@@ -277,7 +277,7 @@ class CfnGitHubRepository(
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableIssues", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="isPrivate")
     def is_private(
         self,
@@ -300,7 +300,7 @@ class CfnGitHubRepository(
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "isPrivate", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="repositoryAccessToken")
     def repository_access_token(self) -> typing.Optional[builtins.str]:
         '''The GitHub user's personal access token for the GitHub repository.
@@ -316,7 +316,7 @@ class CfnGitHubRepository(
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "repositoryAccessToken", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="repositoryDescription")
     def repository_description(self) -> typing.Optional[builtins.str]:
         '''A comment or description about the new repository.
@@ -902,7 +902,7 @@ class IGitHubRepository(aws_cdk.core.IResource, typing_extensions.Protocol):
     :stability: experimental
     '''
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="owner")
     def owner(self) -> builtins.str:
         '''(experimental) the repository owner.
@@ -911,7 +911,7 @@ class IGitHubRepository(aws_cdk.core.IResource, typing_extensions.Protocol):
         '''
         ...
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="repo")
     def repo(self) -> builtins.str:
         '''(experimental) the repository name.
@@ -922,7 +922,7 @@ class IGitHubRepository(aws_cdk.core.IResource, typing_extensions.Protocol):
 
 
 class _IGitHubRepositoryProxy(
-    jsii.proxy_for(aws_cdk.core.IResource) # type: ignore[misc]
+    jsii.proxy_for(aws_cdk.core.IResource), # type: ignore[misc]
 ):
     '''(experimental) GitHubRepository resource interface.
 
@@ -931,7 +931,7 @@ class _IGitHubRepositoryProxy(
 
     __jsii_type__: typing.ClassVar[str] = "@aws-cdk/aws-codestar.IGitHubRepository"
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="owner")
     def owner(self) -> builtins.str:
         '''(experimental) the repository owner.
@@ -940,7 +940,7 @@ class _IGitHubRepositoryProxy(
         '''
         return typing.cast(builtins.str, jsii.get(self, "owner"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="repo")
     def repo(self) -> builtins.str:
         '''(experimental) the repository name.
@@ -1048,7 +1048,7 @@ class GitHubRepository(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="owner")
     def owner(self) -> builtins.str:
         '''(experimental) the repository owner.
@@ -1057,7 +1057,7 @@ class GitHubRepository(
         '''
         return typing.cast(builtins.str, jsii.get(self, "owner"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="repo")
     def repo(self) -> builtins.str:
         '''(experimental) the repository name.
